from .version import VERSION
__version__ = VERSION

from .client import Client
from .pages import Pages
from .patch import Patch
from .resource import Resource
from .response import Response
from . import util
